@@ -384,7 +384,7 @@ class Window:
     def capture(self, region):
         w = region[1][0] - region[0][0]
         h = region[1][1] - region[0][1]
-        wDC = win32gui.GetWindowDC(self.win.hwnd)
+        wDC = win32gui.GetWindowDC(self.hwnd)
         dcObj = win32ui.CreateDCFromHandle(wDC)
         cDC = dcObj.CreateCompatibleDC()
         dataBitMap = win32ui.CreateBitmap()
